@@ -2,10 +2,10 @@
 # pylint: disable=wrong-import-position, invalid-name
 import pytest
 
-numpy = pytest.importorskip('numpy')
-
 import mincepy
 
+numpy = pytest.importorskip("numpy")
+
 
 def test_saving_numpy_arrays(historian: mincepy.Historian):
     array = numpy.ones(10)
@@ -15,7 +15,7 @@ def test_saving_numpy_arrays(historian: mincepy.Historian):
     loaded_array = historian.load(array_id)
     assert all(loaded_array == numpy.ones(10))
 
-    loaded_array[0] = 5.
+    loaded_array[0] = 5.0
     historian.save(loaded_array)
 
 
@@ -27,5 +27,5 @@ def test_saving_numpy_arrays_integers(historian: mincepy.Historian):
     loaded_array = historian.load(array_id)
     assert all(loaded_array == numpy.ones(10, dtype=numpy.int64))
 
-    loaded_array[0] = 5.
+    loaded_array[0] = 5.0
     historian.save(loaded_array)
