@@ -3,7 +3,7 @@
 
 import pytest
 
-pytest.importorskip('rdkit')
+pytest.importorskip("rdkit")
 
 import copy
 
@@ -21,7 +21,7 @@ def create_mol(smiles):
 
 
 def test_rdkit_mol(historian: mincepy.Historian):
-    smiles = 'Cc1ccccc1'
+    smiles = "Cc1ccccc1"
     orig = create_mol(smiles)
     mol = copy.deepcopy(orig)
     oid = historian.save(mol)
@@ -30,6 +30,8 @@ def test_rdkit_mol(historian: mincepy.Historian):
     loaded = historian.load(oid)
     assert Chem.MolToSmiles(loaded) == Chem.MolToSmiles(orig)
     assert loaded.GetNumAtoms() == orig.GetNumAtoms()
-    assert np.allclose(orig.GetConformers()[0].GetPositions(),
-                       loaded.GetConformers()[0].GetPositions(),
-                       atol=1e-4)
+    assert np.allclose(
+        orig.GetConformers()[0].GetPositions(),
+        loaded.GetConformers()[0].GetPositions(),
+        atol=1e-4,
+    )
